@@ -33,10 +33,12 @@ class StorageLocalDiskProps(ManagedObject):
             "copyback_percent_complete": MoPropertyMeta("copyback_percent_complete", "copybackPercentComplete", "string", VersionMeta.Version303a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "device_id": MoPropertyMeta("device_id", "deviceId", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, 0x2, 0, 255, None, [], []),
+            "emulated_block_size": MoPropertyMeta("emulated_block_size", "emulatedBlockSize", "string", VersionMeta.Version422a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "enclosure_device_id": MoPropertyMeta("enclosure_device_id", "enclosureDeviceId", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "health": MoPropertyMeta("health", "health", "string", VersionMeta.Version201a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "interface_type": MoPropertyMeta("interface_type", "interfaceType", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "link_speed": MoPropertyMeta("link_speed", "linkSpeed", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
+            "maximum_operating_temperature": MoPropertyMeta("maximum_operating_temperature", "maximumOperatingTemperature", "string", VersionMeta.Version421a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "media_error_count": MoPropertyMeta("media_error_count", "mediaErrorCount", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "media_type": MoPropertyMeta("media_type", "mediaType", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
             "non_coerced_size": MoPropertyMeta("non_coerced_size", "nonCoercedSize", "string", VersionMeta.Version151f, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
@@ -115,10 +117,12 @@ class StorageLocalDiskProps(ManagedObject):
             "copybackPercentComplete": "copyback_percent_complete", 
             "deviceId": "device_id", 
             "dn": "dn", 
+            "emulatedBlockSize": "emulated_block_size", 
             "enclosureDeviceId": "enclosure_device_id", 
             "health": "health", 
             "interfaceType": "interface_type", 
             "linkSpeed": "link_speed", 
+            "maximumOperatingTemperature": "maximum_operating_temperature", 
             "mediaErrorCount": "media_error_count", 
             "mediaType": "media_type", 
             "nonCoercedSize": "non_coerced_size", 
@@ -195,10 +199,12 @@ class StorageLocalDiskProps(ManagedObject):
         self.copyback_operation_status = None
         self.copyback_percent_complete = None
         self.device_id = None
+        self.emulated_block_size = None
         self.enclosure_device_id = None
         self.health = None
         self.interface_type = None
         self.link_speed = None
+        self.maximum_operating_temperature = None
         self.media_error_count = None
         self.media_type = None
         self.non_coerced_size = None
